dicom_parser.utils package — dicom_parser 0.0.1 documentation

# dicom_parser.utils package

## Subpackages

- dicom_parser.utils.code_strings package
  - Submodules
  - dicom_parser.utils.code_strings.modality module
  - dicom_parser.utils.code_strings.patient_position module
  - dicom_parser.utils.code_strings.scanning_sequence module
  - dicom_parser.utils.code_strings.sequence_variant module
  - dicom_parser.utils.code_strings.sex module
  - Module contents

## Submodules

## dicom_parser.utils.choice_enum module

class `dicom_parser.utils.choice_enum.` `ChoiceEnum`

  Bases: `enum.Enum`

  A small adaptation to python’s built-in `Enum` class.

  `choices` = <bound method ChoiceEnum.choices of <enum 'ChoiceEnum'>>

## dicom_parser.utils.value_representation module

This file contains an Enum with the two-character codes of the various DICOM value-representations (VRs) (also see here) for header data elements.

class `dicom_parser.utils.value_representation.` `ValueRepresentation`

  Bases: `enum.Enum`

  DICOM value-representations (VRs).

  `AGE_STRING` = 'AS'
  `APPLICATION_ENTITY` = 'AE'
  `ATTRIBUTE_TAG` = 'AT'
  `CODE_STRING` = 'CS'
  `DATE` = 'DA'
  `DATE_TIME` = 'DT'
  `DECIMAL_STRING` = 'DS'
  `FLOATING_POINT_DOUBLE` = 'FD'
  `FLOATING_POINT_SINGLE` = 'FL'
  `INTEGER_STRING` = 'IS'
  `LONG_STRING` = 'LO'
  `LONG_TEXT` = 'LT'
  `OTHER_64_BIT_VERY_LONG` = 'OV'
  `OTHER_BYTE` = 'OB'
  `OTHER_DOUBLE` = 'OD'
  `OTHER_FLOAT` = 'OF'
  `OTHER_LONG` = 'OL'
  `OTHER_WORD` = 'OW'
  `PERSON_NAME` = 'PN'
  `SEQUENCE_OF_ITEMS` = 'SQ'
  `SHORT_STRING` = 'SH'
  `SHORT_TEXT` = 'ST'
  `SIGNED_64_BIT_VERY_LONG` = 'SV'
  `SIGNED_LONG` = 'SL'
  `SIGNED_SHORT` = 'SS'
  `TIME` = 'TM'
  `UNIQUE_IDENTIFIER` = 'UI'
  `UNIVERSAL_RESOURCE` = 'UR'
  `UNKNOWN` = 'UN'
  `UNLIMITED_CHARACTERS` = 'UC'
  `UNLIMITED_TEXT` = 'UT'
  `UNSIGNED_64_BIT_VERY_LONG` = 'UV'
  `UNSIGNED_LONG` = 'UL'
  `UNSIGNED_SHORT` = 'US'

## Module contents